@@ -1,8 +1,9 @@
 from datetime import timedelta
 from typing import Any, Dict, Optional, Type
 
-from motor.motor_asyncio import AsyncIOMotorCollection, AsyncIOMotorDatabase
 from pydantic import BaseModel, Field
+from pymongo.asynchronous.collection import AsyncCollection
+from pymongo.asynchronous.database import AsyncDatabase
 
 from beanie.odm.utils.pydantic import IS_PYDANTIC_V2
 
@@ -19,8 +20,8 @@ class ItemSettings(BaseModel):
     bson_encoders: Dict[Any, Any] = Field(default_factory=dict)
     projection: Optional[Dict[str, Any]] = None
 
-    motor_db: Optional[AsyncIOMotorDatabase] = None
-    motor_collection: Optional[AsyncIOMotorCollection] = None
+    pymongo_db: Optional[AsyncDatabase] = None
+    pymongo_collection: Optional[AsyncCollection] = None
 
     union_doc: Optional[Type] = None
     union_doc_alias: Optional[str] = None
