@@ -165,7 +165,7 @@ class DocumentTestModel(Document):
     test_int: int
     test_doc: SubDocument
     test_str: str
-    test_list: List[SubDocument] = Field(exclude=True)
+    test_list: List[SubDocument]
 
     class Settings:
         use_cache = True
@@ -268,9 +268,11 @@ class DocumentTestModelFailInspection(Document):
 
 class DocumentWithDeprecatedHiddenField(Document):
     if IS_PYDANTIC_V2:
-        test_hidden: List[str] = Field(json_schema_extra={"hidden": True})
+        test_hidden: Optional[List[str]] = Field(
+            default=None, json_schema_extra={"hidden": True}
+        )
     else:
-        test_hidden: List[str] = Field(hidden=True)
+        test_hidden: Optional[List[str]] = Field(default=None, hidden=True)
 
 
 class DocumentWithCustomIdUUID(Document):
@@ -568,7 +570,7 @@ class House(Document):
     roof: Optional[Link[Roof]] = None
     yards: Optional[List[Link[Yard]]] = None
     height: Indexed(int) = 2
-    name: Indexed(str) = Field(exclude=True)
+    name: Indexed(str)
 
     if IS_PYDANTIC_V2:
         model_config = ConfigDict(
@@ -905,6 +907,11 @@ class DocumentWithKeepNullsFalse(Document):
         use_state_management = True
 
 
+class DocumentWithExcludedField(Document):
+    included_field: int
+    excluded_field: Optional[int] = Field(default=None, exclude=True)
+
+
 class ReleaseElemMatch(BaseModel):
     major_ver: int
     minor_ver: int
